@@ -1,5 +1,5 @@
 /*
- * $Id: command.h,v 1.57 2011/10/03 00:17:22 sfeam Exp $
+ * $Id: command.h,v 1.66.2.2 2015/05/22 23:34:06 sfeam Exp $
  */
 
 /* GNUPLOT - command.h */
@@ -78,12 +78,9 @@ extern int paused_for_mouse;	/* Flag the end condition we are paused until */
 #define PAUSE_ANY       077		/* Terminate on any of the above */
 #endif
 
-#ifdef GP_MACROS
-extern TBOOLEAN expand_macros;
-#endif
-
 /* output file for the print command */
 extern FILE *print_out;
+extern struct udvt_entry * print_out_var;
 extern char *print_out_name;
 
 extern struct udft_entry *dummy_func;
@@ -92,10 +89,8 @@ extern struct udft_entry *dummy_func;
 # define STDOUT 1
 #endif
 
-#if defined(MSDOS)
-# ifdef DJGPP
+#if defined(MSDOS) && defined(DJGPP)
 extern char HelpFile[];         /* patch for do_help  - AP */
-# endif                         /* DJGPP */
 #endif /* MSDOS */
 
 #ifdef _Windows
@@ -106,9 +101,9 @@ extern char HelpFile[];         /* patch for do_help  - AP */
 # define SET_CURSOR_ARROW       /* nought, zilch */
 #endif
 
-/* wrapper for calling kill_pending_Pause_dialog() from win/winmain.c */
-#ifdef _Windows
-void call_kill_pending_Pause_dialog(void);
+/* Include code to support deprecated "call" syntax. */
+#ifdef BACKWARDS_COMPATIBLE
+#define OLD_STYLE_CALL_ARGS
 #endif
 
 /* input data, parsing variables */
@@ -139,9 +134,7 @@ extern void wxt_raise_terminal_group __PROTO((void));
 extern void wxt_lower_terminal_window __PROTO((int));
 extern void wxt_lower_terminal_group __PROTO((void));
 #endif
-#ifdef GP_MACROS
-extern int string_expand_macros __PROTO((void));
-#endif
+extern void string_expand_macros __PROTO((void));
 
 #ifdef USE_MOUSE
 void bind_command __PROTO((void));
@@ -149,9 +142,8 @@ void restore_prompt __PROTO((void));
 #else
 #define bind_command()
 #endif
-#ifdef VOLATILE_REFRESH
 void refresh_request __PROTO((void));
-#endif
+void refresh_command __PROTO((void));
 void call_command __PROTO((void));
 void changedir_command __PROTO((void));
 void clear_command __PROTO((void));
@@ -162,7 +154,9 @@ void history_command __PROTO((void));
 void do_command __PROTO((void));
 void if_command __PROTO((void));
 void else_command __PROTO((void));
+void import_command __PROTO((void));
 void invalid_command __PROTO((void));
+void link_command __PROTO((void));
 void load_command __PROTO((void));
 void begin_clause __PROTO((void));
 void clause_reset_after_error __PROTO((void));
@@ -171,8 +165,8 @@ void null_command __PROTO((void));
 void pause_command __PROTO((void));
 void plot_command __PROTO((void));
 void print_command __PROTO((void));
+void printerr_command __PROTO((void));
 void pwd_command __PROTO((void));
-void refresh_command __PROTO((void));
 void replot_command __PROTO((void));
 void reread_command __PROTO((void));
 void save_command __PROTO((void));
@@ -205,7 +199,7 @@ void define __PROTO((void));
 
 void replotrequest __PROTO((void)); /* used in command.c & mouse.c */
 
-void print_set_output __PROTO((char *, TBOOLEAN)); /* set print output file */
+void print_set_output __PROTO((char *, TBOOLEAN, TBOOLEAN)); /* set print output file */
 char *print_show_output __PROTO((void)); /* show print output file */
 
 /* Activate/deactive effects of 'set view map' before 'splot'/'plot',
