@@ -1,5 +1,5 @@
 /*
- * $Id: graph3d.h,v 1.38.2.1 2009/12/20 03:54:42 sfeam Exp $
+ * $Id: graph3d.h,v 1.47 2014/04/22 20:49:28 sfeam Exp $
  */
 
 /* GNUPLOT - graph3d.h */
@@ -97,6 +97,7 @@ typedef struct surface_points {
     enum PLOT_TYPE plot_type;	/* DATA2D? DATA3D? FUNC2D FUNC3D? NODATA? */
     enum PLOT_STYLE plot_style;	/* style set by "with" or by default */
     char *title;		/* plot title, a.k.a. key entry */
+    int title_position;		/* -1 for beginning; +1 for end */
     TBOOLEAN title_no_enhanced;	/* don't typeset title in enhanced mode */
     TBOOLEAN title_is_filename;	/* not used in 3D */
     TBOOLEAN title_is_suppressed;/* TRUE if 'notitle' was specified */
@@ -106,6 +107,7 @@ typedef struct surface_points {
     struct fill_style_type fill_properties;	/* FIXME: ignored in 3D */
     struct text_label *labels;	/* Only used if plot_style == LABELPOINTS */
     struct t_image image_properties;	/* only used if plot_style is IMAGE or RGB_IMAGE */
+    struct udvt_entry *sample_var;	/* Only used if plot has private sampling range */
 
     /* 2D and 3D plot structure fields overlay only to this point */
 
@@ -113,6 +115,7 @@ typedef struct surface_points {
     TBOOLEAN opt_out_of_contours; /* set by "nocontours" option to splot command */
     TBOOLEAN opt_out_of_surface;  /* set by "nosurface" option to splot command */
     TBOOLEAN pm3d_color_from_column;
+    int hidden3d_top_linetype;	/* before any calls to load_linetype() */
     int has_grid_topology;
     int iteration;		/* needed for tracking iteration */
 
@@ -135,9 +138,13 @@ extern double xscale3d, yscale3d, zscale3d;
 extern double xcenter3d, ycenter3d, zcenter3d;
 
 extern t_contour_placement draw_contour;
-extern TBOOLEAN	label_contours;
+extern TBOOLEAN	clabel_onecolor;
+extern int clabel_start;
+extern int clabel_interval;
+extern char *clabel_font;
 
 extern TBOOLEAN	draw_surface;
+extern TBOOLEAN	implicit_surface;
 
 /* is hidden3d display wanted? */
 extern TBOOLEAN	hidden3d;
@@ -147,6 +154,8 @@ extern float surface_rot_z;
 extern float surface_rot_x;
 extern float surface_scale;
 extern float surface_zscale;
+extern float surface_lscale;
+extern float mapview_scale;
 extern int splot_map;
 
 typedef struct { 
