@@ -1,5 +1,5 @@
 /*
- * $Id: parse.h,v 1.25 2011/07/22 14:37:57 juhaszp Exp $
+ * $Id: parse.h,v 1.29.2.2 2016/01/11 23:32:50 sfeam Exp $
  */
 
 /* GNUPLOT - parse.h */
@@ -50,6 +50,9 @@ extern TBOOLEAN scanning_range_in_progress;
 /* The choice of dummy variables, as set by 'set dummy', 'set polar'
  * and 'set parametric' */
 extern char set_dummy_var[MAX_NUM_VAR][MAX_ID_LEN+1];
+/* Dummy variables referenced by name in a fit command */
+/* Sep 2014 (DEBUG) used to deduce how many independent variables */
+extern int  fit_dummy_var[MAX_NUM_VAR];
 /* the currently used 'dummy' variables. Usually a copy of
  * set_dummy_var, but may be changed by the '(s)plot' command
  * containing an explicit range (--> 'plot [phi=0..pi]') */
@@ -61,10 +64,17 @@ extern int at_highest_column_used;
 /* This is checked by df_readascii() */
 extern TBOOLEAN parse_1st_row_as_headers;
 
+/* Protection mechanism for trying to parse a string followed by a + or - sign.
+ * Also suppresses an undefined variable message if an unrecognized token
+ * is encountered during try_to_get_string().
+ */
+extern TBOOLEAN string_result_only;
+
 /* Prototypes of exported functions in parse.c */
 
 int int_expression __PROTO(());
 double real_expression __PROTO(());
+void parse_reset_after_error __PROTO(());
 struct value * const_string_express __PROTO((struct value *valptr));
 struct value * const_express __PROTO((struct value *valptr));
 char* string_or_express __PROTO((struct at_type **atptr));
@@ -99,6 +109,9 @@ extern t_iterator * set_iterator;		/* Used by set/unset commands */
 t_iterator * check_for_iteration __PROTO((void));
 TBOOLEAN next_iteration  __PROTO((t_iterator *));
 TBOOLEAN empty_iteration  __PROTO((t_iterator *));
+TBOOLEAN forever_iteration  __PROTO((t_iterator *));
 t_iterator * cleanup_iteration __PROTO((t_iterator *));
 
+void parse_link_via __PROTO((struct udft_entry *));
+
 #endif /* PARSE_H */
