@@ -1,5 +1,5 @@
 /*
- * $Id: stdfn.h,v 1.32.4.1 2010/01/06 17:35:10 sfeam Exp $
+ * $Id: stdfn.h,v 1.49.2.1 2015/08/17 05:47:29 sfeam Exp $
  */
 
 /* GNUPLOT - stdfn.h */
@@ -44,11 +44,11 @@
 #ifndef STDFN_H
 #define STDFN_H
 
+#include "syscfg.h"
+
 #include <ctype.h>
 #include <stdio.h>
 
-#include "syscfg.h"
-
 #ifdef HAVE_STRING_H
 # include <string.h>
 #else
@@ -134,6 +134,10 @@ double strtod();
 # endif /* VMS */
 #endif /* HAVE_STDLIB_H */
 
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+
 /* Deal with varargs functions */
 #if defined(HAVE_VFPRINTF) || defined(HAVE_DOPRNT)
 # ifdef STDC_HEADERS
@@ -261,7 +265,11 @@ extern char *sys_errlist[];
 # define time_t long
 #endif
 
-#if defined(PIPES) && (defined(VMS) || (defined(OSK) && defined(_ANSI_EXT))) || defined(PIPES) && defined(AMIGA_SC_6_1)
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h> /* for gettimeofday() */
+#endif
+
+#if defined(PIPES) && defined(VMS)
 FILE *popen __PROTO((char *, char *));
 int pclose __PROTO((FILE *));
 #endif
@@ -320,6 +328,19 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 # endif
 #endif
 
+#ifndef HAVE_STRNDUP
+char *strndup __PROTO((const char * str, size_t n));
+#endif
+
+#ifndef HAVE_STRNLEN
+size_t strnlen __PROTO((const char *str, size_t n));
+#endif
+
+#if defined(_MSC_VER)
+int ms_vsnprintf(char *str, size_t size, const char *format, va_list ap);
+int ms_snprintf(char *str, size_t size, const char * format, ...);
+#endif
+
 #ifndef GP_GETCWD
 # if defined(HAVE_GETCWD)
 #   if defined(__EMX__)
@@ -355,20 +376,65 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 #endif
 
 #ifndef GP_SLEEP
-# ifdef __ZTC__
-#    define GP_SLEEP(delay) usleep ((unsigned long) (delay+0.5))
-# else
-#    define GP_SLEEP(delay) sleep ((unsigned int) (delay+0.5))
-# endif
+#  define GP_SLEEP(delay) sleep ((unsigned int) (delay+0.5))
 #endif
 
-#ifdef HAVE_ATEXIT
-# define GP_ATEXIT(x) atexit((x))
-#elif defined(HAVE_ON_EXIT)
-# define GP_ATEXIT(x) on_exit((x),0)
-#else
-# define GP_ATEXIT(x) /* you lose */
-#endif
+/* Gnuplot replacement for atexit(3) */
+void gp_atexit __PROTO((void (*function)(void)));
+
+/* Gnuplot replacement for exit(3). Calls the functions registered using
+ * gp_atexit(). Always use this function instead of exit(3)!
+ */
+void gp_exit __PROTO((int status));
+
+/* Calls the cleanup functions registered using gp_atexit().
+ * Normally gnuplot should be exited using gp_exit(). In some cases, this is not
+ * possible (notably when returning from main(), where some compilers get
+ * confused because they expect a return statement at the very end. In that
+ * case, gp_exit_cleanup() should be called before the return statement.
+ */
+void gp_exit_cleanup __PROTO((void));
+
+char * gp_basename __PROTO((char *path));
+
+#if !defined(HAVE_DIRENT_H) && defined(WIN32) && (!defined(__WATCOMC__))
+/*
+
+    Declaration of POSIX directory browsing functions and types for Win32.
+
+    Author:  Kevlin Henney (kevlin@acm.org, kevlin@curbralan.com)
+    History: Created March 1997. Updated June 2003.
+*/
+/*
+
+    Copyright Kevlin Henney, 1997, 2003. All rights reserved.
+
+    Permission to use, copy, modify, and distribute this software and its
+    documentation for any purpose is hereby granted without fee, provided
+    that this copyright and permissions notice appear in all copies and
+    derivatives.
+    
+    This software is supplied "as is" without express or implied warranty.
+
+    But that said, if there are any problems please get in touch.
+
+*/
+typedef struct DIR DIR;
+
+struct dirent
+{
+    char *d_name;
+};
+
+DIR           *opendir __PROTO((const char *));
+int           closedir __PROTO((DIR *));
+struct dirent *readdir __PROTO((DIR *));
+void          rewinddir __PROTO((DIR *));
+#elif defined(HAVE_DIRENT_H)
+# include <sys/types.h>
+# include <dirent.h>
+#endif /* !HAVE_DIRENT_H && WIN32 */
+
 
 /* Misc. defines */
 
@@ -377,7 +443,11 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 
 /* Definitions for debugging */
 /* #define NDEBUG */
-#include <assert.h>
+/* #include <assert.h> */
+#ifndef assert
+#define assert(X) if (!(X)) int_error(-1,"Assertion failed: %s", #X )
+#endif
+
 
 #ifdef DEBUG
 # define DEBUG_WHERE do { fprintf(stderr,"%s:%d ",__FILE__,__LINE__); } while (0)
@@ -469,8 +539,12 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 #ifdef HAVE_SYS_PARAM_H
 # include <sys/param.h>
 #endif
+/* HBB 2012-03-18: clang brings its own <limits.h>, which lacks PATH_MAX,
+ * and on top of that, Cygwin's MAXPATHLEN is defined by reference to PATH_MAX.
+ * So even though clang sees a #defined MAXPATHLEN, there's still no 
+ * definition available OA*/
 #ifndef PATH_MAX
-# ifndef MAXPATHLEN
+# if !defined(MAXPATHLEN) || (MAXPATHLEN <= 0)
 #  define PATH_MAX 1024
 # else
 #  define PATH_MAX MAXPATHLEN
@@ -481,6 +555,7 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
  * may or may not end with a "directory separation" character.
  * Path must not be NULL, but can be empty
  */
+#ifndef VMS
 #define PATH_CONCAT(path,file) \
  { char *p = path; \
    p += strlen(path); \
@@ -490,6 +565,9 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
    } \
    strcat (path, file); \
  }
+#else
+#define PATH_CONCAT(path,file) strcat(path,file)
+#endif
 
 #ifndef inrange
 # define inrange(z,min,max) \
@@ -498,7 +576,7 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 #endif
 
 /* HBB 20030117: new macro to simplify clipping operations in the
- * presence of possibly reverted axes */
+ * presence of possibly reversed axes */
 #ifndef cliptorange
 # define cliptorange(z,min,max)			\
     do {					\
@@ -522,6 +600,11 @@ int gp_strnicmp __PROTO((const char *, const char *, size_t));
 #define GPMAX(a,b) ( (a) > (b) ? (a) : (b) )
 #define GPMIN(a,b) ( (a) < (b) ? (a) : (b) )
 
+/*
+ * Do any supported platforms already have a sgn function?
+ */
+#define sgn(x) (((x) > 0) ? 1 : (((x) < 0) ? -1 : 0))
+
 /* Prototypes from "stdfn.c" */
 
 char *safe_strncpy __PROTO((char *, const char *, size_t));
@@ -529,8 +612,6 @@ char *safe_strncpy __PROTO((char *, const char *, size_t));
 unsigned int sleep __PROTO((unsigned int));
 #endif
 
-double gp_strtod __PROTO((const char *str, char **endptr));
-
 double not_a_number __PROTO((void));
 
 #endif /* STDFN_H */
