@@ -1,5 +1,5 @@
 /*
- * $Id: util.h,v 1.36.2.2 2012/09/26 23:03:15 sfeam Exp $
+ * $Id: util.h,v 1.44 2014/04/05 06:17:09 markisch Exp $
  */
 
 /* GNUPLOT - util.h */
@@ -75,7 +75,6 @@ int isletter __PROTO((int));
 int is_definition __PROTO((int));
 void copy_str __PROTO((char *, int, int));
 size_t token_len __PROTO((int));
-void quote_str __PROTO((char *, int, int));
 void capture __PROTO((char *, int, int, int));
 void m_capture __PROTO((char **, int, int));
 void m_quote_capture __PROTO((char **, int, int));
@@ -98,6 +97,10 @@ void gprintf __PROTO((char *, size_t, char *, double, double));
     void os_error __PROTO((int, const char *, ...)) __attribute__((noreturn));
     void int_error __PROTO((int, const char *, ...)) __attribute__((noreturn));
     void graph_error __PROTO((const char *, ...)) __attribute__((noreturn));
+#  elif defined(_MSC_VER)
+    __declspec(noreturn) void os_error(int, const char *, ...);
+    __declspec(noreturn) void int_error(int, const char *, ...);
+    __declspec(noreturn) void graph_error(const char *, ...);
 #  else
     void os_error __PROTO((int, const char *, ...));
     void int_error __PROTO((int, const char *, ...));
@@ -118,6 +121,7 @@ void graph_error __PROTO(());
 void squash_spaces __PROTO((char *));
 
 TBOOLEAN existdir __PROTO((const char *));
+TBOOLEAN existfile(const char *);
 
 char *getusername __PROTO((void));
 
@@ -127,5 +131,13 @@ size_t strlen_utf8 __PROTO((const char *s));
 size_t gp_strlen __PROTO((const char *s));
 char * gp_strchrn __PROTO((const char *s, int N));
 TBOOLEAN streq __PROTO((const char *a, const char *b));
+size_t strappend(char **dest, size_t *size, size_t len, const char *src);
+
+char *num_to_str(double r);
+char *value_to_str(struct value *val, TBOOLEAN need_quotes);
+
+/* To disallow 8-bit characters in variable names, set this to */
+/* #define ALLOWED_8BITVAR(c) FALSE */
+#define ALLOWED_8BITVAR(c) ((c)&0x80)
 
 #endif /* GNUPLOT_UTIL_H */
