@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: version.c,v 1.100.2.7 2013/04/11 20:04:07 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: version.c,v 1.111.2.11 2016/02/22 04:26:05 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - version.c */
@@ -39,10 +39,14 @@ static char *RCSid() { return RCSid("$Id: version.c,v 1.100.2.7 2013/04/11 20:04
 #include "syscfg.h"		/* for FAQ_LOCATION */
 
 
-const char gnuplot_version[] = "4.6";
+const char gnuplot_version[] = "5.0";
 const char gnuplot_patchlevel[] = "3";
-const char gnuplot_date[] = "2013-04-12 ";
-const char gnuplot_copyright[] = "Copyright (C) 1986-1993, 1998, 2004, 2007-2013";
+#ifdef DEVELOPMENT_VERSION
+#include "timestamp.h"
+#else
+const char gnuplot_date[] = "2016-02-21 ";
+#endif
+const char gnuplot_copyright[] = "Copyright (C) 1986-1993, 1998, 2004, 2007-2016";
 
 const char faq_location[] = FAQ_LOCATION;
 
@@ -50,6 +54,3 @@ char *compile_options = (void *)0;	/* Will be loaded at runtime */
 
 const char bug_email[] = "gnuplot-beta@lists.sourceforge.net";
 const char help_email[] = "gnuplot-beta@lists.sourceforge.net";
-
-char os_name[32];
-char os_rel[32];
