@@ -1,5 +1,5 @@
 /*
- * $Id: wgnuplib.h,v 1.53 2011/11/18 07:48:28 markisch Exp $
+ * $Id: wgnuplib.h,v 1.65.2.2 2014/12/31 04:38:44 sfeam Exp $
  */
 
 /* GNUPLOT - win/wgnuplib.h */
@@ -40,7 +40,15 @@
  *   Russell Lang
  */
 
+#ifndef WGNUPLIB_H
+#define WGNUPLIB_H
+
 #include <windows.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "screenbuf.h"
 #include "term_api.h"
 
@@ -109,6 +117,7 @@ typedef struct tagPW
 } PW;
 typedef PW *  LPPW;
 
+TBOOLEAN MousableWindowOpened(void);
 int WDPROC PauseBox(LPPW lppw);
 
 /* ================================== */
@@ -202,6 +211,8 @@ int WDPROC TextGetChE(LPTW);
 LPSTR WDPROC TextGetS(LPTW lptw, LPSTR str, unsigned int size);
 int WDPROC TextPutCh(LPTW, BYTE);
 int WDPROC TextPutS(LPTW lptw, LPSTR str);
+void TextStartEditing(LPTW lptw);
+void TextStopEditing(LPTW lptw);
 #if 0
 /* The new screen buffer currently does not support these */
 void WDPROC TextGotoXY(LPTW lptw, int x, int y);
@@ -228,12 +239,16 @@ void WDPROC AboutBox(HWND hwnd, LPSTR str);
  * by the 'Line styles...' dialog, and save to/from wgnuplot.ini). */
 #define WGNUMPENS 15
 
-/* maximum number of plots which can be enabled/disabled via toolbar */
-#define MAXPLOTSHIDE 10
-
 /* maximum number of different colors per palette, used to be hardcoded (256) */
 #define WIN_PAL_COLORS 4096
 
+/* hypertext structure
+*/
+struct tooltips {
+	LPWSTR text;
+	RECT rect;
+};
+
 /* Information about one graphical operation to be stored by the
  * driver for the sake of redraws. Array of GWOP kept in global block */
 struct GWOP {
@@ -289,6 +304,10 @@ struct GWOPBLK {			/* kept in local memory */
 #define W_image 45
 #define W_layer 46
 #define W_text_encoding 47
+#define W_hypertext 48
+#define W_boxedtext 49
+#define W_dash_type 50
+
 
 typedef struct tagGW {
 	GP_LPPRINT	lpr;		/* must be first */
@@ -309,6 +328,11 @@ typedef struct tagGW {
 	HWND	hToolbar;
 	int		ToolbarHeight;
 	HMENU	hPopMenu;	/* popup menu */
+	HBITMAP	hBitmap;	/* bitmap of current graph */
+	BOOL	buffervalid;	/* indicates if hBitmap is valid */
+	BOOL	rotating;	/* are we currently rotating the graph? */
+	POINT	Canvas;		/* requested size of the canvas */
+	POINT	Decoration;	/* extent of the window decorations */
 
 	struct GWOPBLK *gwopblk_head;
 	struct GWOPBLK *gwopblk_tail;
@@ -319,19 +343,28 @@ typedef struct tagGW {
 	BOOL	graphtotop;	/* bring graph window to top after every plot? */
 	BOOL	color;		/* color pens? */
 	BOOL	dashed;		/* dashed lines? */
+	BOOL	rounded;	/* rounded line caps and joins? */
 	BOOL	doublebuffer;	/* double buffering? */
 	BOOL	oversample;	/* oversampling? */
-	BOOL	antialiasing;
+	BOOL	gdiplus;	/* Use GDI+ only backend? */
+	BOOL	antialiasing;	/* anti-aliasing? */
 	BOOL	polyaa;		/* anti-aliasing for polygons ? */
 	BOOL	patternaa;	/* anti-aliasing for polygons ? */
+	BOOL	fastrotation;	/* rotate without anti-aliasing? */
 
-	BOOL	hideplot[MAXPLOTSHIDE];
+	BOOL	*hideplot;
+	unsigned int maxhideplots;
 	BOOL	hidegrid;
 	unsigned int numplots;
 	BOOL	hasgrid;
 	LPRECT	keyboxes;
 	unsigned int maxkeyboxes;
 
+	HWND	hTooltip;	/* tooltip windows for hypertext */
+	struct tooltips * tooltips;
+	unsigned int maxtooltips;
+	unsigned int numtooltips;
+
 	int		htic;		/* horizontal size of point symbol (xmax units) */
 	int 	vtic;		/* vertical size of point symbol (ymax units)*/
 	int		hchar;		/* horizontal size of character (xmax units) */
@@ -351,6 +384,9 @@ typedef struct tagGW {
 	int		encoding_error; /* last unknown encoding */
 	double	fontscale;	/* scale factor for font sizes */
 	enum set_encoding_id encoding;	/* text encoding */
+	LONG	tmHeight;	/* text metric of current font */
+	LONG	tmAscent;
+	LONG	tmDescent;
 
 	HPEN	hapen;		/* stored current pen */
 	HPEN	hsolid;		/* solid sibling of current pen */
@@ -363,7 +399,7 @@ typedef struct tagGW {
 	COLORREF background;		/* background color */
 	HBRUSH	hbrush;				/* background brush */
 	HBRUSH	hcolorbrush;		/* */
-	int		sampling;	/* current sampling factor */
+	int		sampling;			/* current sampling factor */
 
 	struct tagGW * next;		/* pointer to next window */
 } GW;
@@ -382,6 +418,7 @@ extern int WIN_inifontsize;
 
 void WDPROC GraphInitStruct(LPGW lpgw);
 void WDPROC GraphInit(LPGW lpgw);
+void WDPROC GraphUpdateWindowPosSize(LPGW lpgw);
 void WDPROC GraphClose(LPGW lpgw);
 void WDPROC GraphStart(LPGW lpgw, double pointsize);
 void WDPROC GraphEnd(LPGW lpgw);
@@ -391,8 +428,10 @@ void WDPROC GraphOp(LPGW lpgw, UINT op, UINT x, UINT y, LPCSTR str);
 void WDPROC GraphOpSize(LPGW lpgw, UINT op, UINT x, UINT y, LPCSTR str, DWORD size);
 void WDPROC GraphPrint(LPGW lpgw);
 void WDPROC GraphRedraw(LPGW lpgw);
+void WDPROC GraphModifyPlots(LPGW lpgw, unsigned int operations);
 void WDPROC win_close_terminal_window(LPGW lpgw);
 TBOOLEAN GraphHasWindow(LPGW lpgw);
+char * GraphDefaultFont(void);
 
 #ifdef USE_MOUSE
 void WDPROC Graph_set_cursor(LPGW lpgw, int c, int x, int y);
@@ -410,3 +449,9 @@ void WIN_update_options __PROTO((void));
 
 
 /* ================================== */
+
+#ifdef __cplusplus
+};
+#endif
+
+#endif
